<?php
namespace Opencart\Catalog\Model\Extension\IdPaymentBerekeBank\Payment;
require_once 'include.php';
class Gateway {
public $prod_url;
public $test_url;
public $alternative_domain;
public $allowCallbacks;
public $enable_cart_options;
public $enable_refund_options;
public $enable_back_url_settings;
public $module_version = "1.0.4b";
public $method_title = RBSPAYMENT_BEREKEBANK_PAYMENT_NAME;
public $test_mode;
public $stage_mode;
public $versionFfd;
public $paymentMethodType = 1;
public $paymentObjectType = 1;
public $paymentMethodTypeDelivery = 1;
public $taxSystem = 1;
public $taxType = 1;
public $api_version = 1;
public function __construct($params = array())
{
foreach ($params as $key => $value) {
$this->$key = $value;
}
$this->test_url = RBSPAYMENT_BEREKEBANK_TEST_URL;
$this->prod_url = RBSPAYMENT_BEREKEBANK_PROD_URL;
if (defined('RBSPAYMENT_BEREKEBANK_API_VERSION')) {
$this->api_version = RBSPAYMENT_BEREKEBANK_API_VERSION;
}
$this->allowCallbacks = RBSPAYMENT_BEREKEBANK_ENABLE_CALLBACK;
if (defined('RBSPAYMENT_BEREKEBANK_PROD_URL_ALTERNATIVE_DOMAIN')) {
$this->alternative_domain = RBSPAYMENT_BEREKEBANK_PROD_URL_ALTERNATIVE_DOMAIN;
}
if (defined('RBSPAYMENT_BEREKEBANK_PROD_URL_ALTERNATIVE_DOMAIN') && defined('RBSPAYMENT_BEREKEBANK_PROD_URL_ALT_PREFIX')) {
}
if (defined('RBSPAYMENT_BEREKEBANK_ENABLE_CART_OPTIONS') && RBSPAYMENT_BEREKEBANK_ENABLE_CART_OPTIONS === true) {
$this->enable_cart_options = true;
} else {
$this->enable_cart_options = false;
}
if (defined('RBSPAYMENT_BEREKEBANK_ENABLE_REFUNDS') && RBSPAYMENT_BEREKEBANK_ENABLE_REFUNDS === true) {
$this->enable_refund_options = true;
} else {
$this->enable_refund_options = false;
}
if (defined('RBSPAYMENT_BEREKEBANK_ENABLE_BACK_URL_SETTINGS') && RBSPAYMENT_BEREKEBANK_ENABLE_BACK_URL_SETTINGS === true) {
$this->enable_back_url_settings = true;
}
}
public function __test($data) {
var_dump($data);
die;
}
public function _updateGatewaySettings($callback_addresses_string, $fields_data) {
if (!empty($fields_data['payment_berekebank_payment_merchant_token'])) {
$decoded_credentials = base64_decode($fields_data['payment_berekebank_payment_merchant_token']);
list($l, $p) = explode(':', $decoded_credentials);
$login = $l;
$password = $p;
} else {
$login = $fields_data['payment_berekebank_payment_merchant_login'];
$password = $fields_data['payment_berekebank_payment_merchant_password'];
}
if ($fields_data['payment_berekebank_payment_test_mode']) {
$action_adr = $this->test_url;
$gate_url = str_replace("payment/rest", "mportal/mvc/public/merchant/update", $action_adr);
} else {
$action_adr = $this->prod_url;
$gate_url = str_replace("payment/rest", "mportal/mvc/public/merchant/update", $action_adr);
$alternative_domain = $this->alternative_domain;
if (!is_null($alternative_domain)) {
$pattern = '/^https:\/\/[^\/]+/';
$gate_url = preg_replace($pattern, rtrim($alternative_domain, '/'), $gate_url);
}
}
$gate_url .= substr($login, 0, -4);
$headers = array(
'Content-Type:application/json',
'Authorization: Basic ' . base64_encode($login . ":" . $password)
);
$data['callbacks_enabled'] = true;
$data['callback_type'] = "STATIC";
$data['callback_http_method'] = "GET";
$data['callback_operations'] = "deposited,approved,declinedByTimeout";
$data['callback_addresses'] = $callback_addresses_string;
$response = $this->_sendGatewayData(json_encode($data), $gate_url, $headers);
$this->writeLog("REQUEST:\n". $gate_url . "\n[callback_addresses_string]: " . $callback_addresses_string . "\nRESPONSE:\n" . $response);
}
/**
* @param $data
* @param $action_address
* @param array $headers
* @return string
*/
public function _sendGatewayData($data, $action_address, $headers = array(), $ca_info = null)
{
$curl_opt = array(
CURLOPT_HTTPHEADER => $headers,
CURLOPT_VERBOSE => true,
CURLOPT_SSL_VERIFYHOST => false,
CURLOPT_URL => $action_address,
CURLOPT_RETURNTRANSFER => true,
CURLOPT_POST => true,
CURLOPT_POSTFIELDS => $data,
CURLOPT_HEADER => true,
);
$ssl_verify_peer = false;
if ($ca_info != null) {
$ssl_verify_peer = true;
$curl_opt[CURLOPT_CAINFO] = $ca_info;
}
$curl_opt[CURLOPT_SSL_VERIFYPEER] = $ssl_verify_peer;
$ch = curl_init();
curl_setopt_array($ch, $curl_opt);
$response = curl_exec($ch);
if ($response === false) {
}
$header_size = curl_getinfo($ch, CURLINFO_HEADER_SIZE);
curl_close($ch);
return substr($response, $header_size);
}
/**
* @return string
*/
public function getTestUrl()
{
return $this->test_url;
}
/**
* @return string
*/
public function getProdUrl()
{
return $this->prod_url;
}
public function getDefaultMeasurement()
{
if ($this->versionFfd == "v1_05") {
return RBSPAYMENT_BEREKEBANK_MEASUREMENT_NAME;
}
return RBSPAYMENT_BEREKEBANK_MEASUREMENT_CODE;
}
/**
* @param $delivery
* @return mixed
*/
public function getPaymentMethodType($delivery = false)
{
if ($delivery) {
return $this->paymentMethodTypeDelivery;
}
return $this->paymentMethodType;
}
/**
* @return mixed
*/
public function getPaymentObjectType()
{
return $this->paymentObjectType;
}
/**
* @return string
*/
public function getAlternativeDomain()
{
return $this->alternative_domain;
}
public function _getGatewayOrderStatus($args, $orderId) {
if ($this->test_mode) {
$action_address = $this->test_url . "getOrderStatusExtended.do";
} else {
$action_address = $this->prod_url . "getOrderStatusExtended.do";
}
$args['orderId'] = $orderId;
return $this->_sendGatewayData($args, $action_address);
}
function writeLog($var, $info = true) {
$information = "";
if ($var) {
if ($info) {
$information = "\n\n";
$information .= str_repeat("-=", 64);
$information .= "\nDate: " . date('Y-m-d H:i:s');
$information .= "\nOpenCart v." . VERSION . "\n";
}
$result = $var;
if (is_array($var) || is_object($var)) {
$result = "\n" . print_r($var, true);
}
$result .= "\n\n";
$path = dirname(__FILE__) . '/../oc_iddev_' . date('Y-m') . '.log';
error_log($information . $result, 3, $path);
}
}
}